<img align="right" src="https://its-called-hentai-and-its.art/9e83af1581.png" height="150" width="150">

# Lavalink.py

Lavalink.py serves to be an interface with various utilities to make interacting with Lavalink easier!

# Download Lavalink

[Lavalink V2](https://ci.fredboat.com/viewType.html?buildTypeId=Lavalink_Build&branch_Lavalink=%3Cdefault%3E&tab=buildTypeStatusDiv)

[Lavalink V3](https://ci.fredboat.com/viewType.html?buildTypeId=Lavalink_Build&branch_Lavalink=refs%2Fheads%2Fv3&tab=buildTypeStatusDiv)

# Getting Started

There aren't currently any docs for Lavalink.py at the time of writing (sorry!). We recommend that you check out the example music cogs, or check out the source itself!

If you're using Lavalink V3, check out [examples/music-v3.py](https://github.com/Devoxin/Lavalink.py/blob/master/examples/music-v3.py)

For Lavalink V2 users, check [examples/music-v2.py](https://github.com/Devoxin/Lavalink.py/blob/master/examples/music-v2.py)

# Links

[Lavalink Wiki](https://github.com/Devoxin/Lavalink.py/wiki)

[Get Support](https://discord.gg/SbJXU9s)
